==> landing-page-webflow-scripts-1.1.8.tgz: package/src/util/gtm/tags-collection.js <==
// -------------------------------------------------------
// HOME - PAGE
// -------------------------------------------------------
/**
 * GTM Toolbar buyer-registration button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'registration',
};

/**
 * GTM root page hero registration - button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickHero = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'hero',
};

/**
 * GTM toolbar login button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickLogin = {
  event: 'user-click-login',
  category: 'user',
  action: 'click',
  label: 'login',
};

// -------------------------------------------------------
// EVERYWHERE
// -------------------------------------------------------
/**
 * GTM chatbot click
 */
export const chatBotClick = {
  event: 'user-click-chatbot',
  category: 'user',
  action: 'click',
  label: 'chatbot',
};

// -------------------------------------------------------
// CAMPAIGN
// -------------------------------------------------------
/**
 * toolbar
 */
export const campaignToolbarClick = {
  event: 'campaign-click-toolbar',
  category: 'campaign',
  action: 'click',
  label: 'toolbar',
};

/**
 * hero
 */
export const campaignHeroClick = {
  event: 'campaign-click-hero',
  category: 'campaign',
  action: 'click',
  label: 'hero',
};

/**
 * book a demo (middle section)
 */
export const campaignBookADemo = {
  event: 'campaign-click-Book-a-demo',
  category: 'campaign',
  action: 'click',
  label: 'book a demo',
};

/**
 * book a demo (footer)
 */
export const campaignBookADemoFooter = {
  event: 'campaign-click-footer',
  category: 'campaign',
  action: 'click',
  label: 'footer',
};

==> landing-page-webflow-scripts-1.1.9.tgz: package/src/util/gtm/tags-collection.js <==
// -------------------------------------------------------
// HOME - PAGE
// -------------------------------------------------------
/**
 * GTM toolbar buyer-registration button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'header-registration',
};

/**
 * GTM home page hero registration - button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickHeroRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'hero-registration',
};

/**
 * GTM home page auction - registration
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickAuctionRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'auction-registration',
};

/**
 * GTM  page faq - registration
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickFAQRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'faq-registration',
};

/**
 * GTM home page footer - registration
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickFooterRegistration = {
  event: 'user-click-registration',
  category: 'user',
  action: 'click',
  label: 'footer-registration',
};

/**
 * GTM toolbar login button
 * @type {{action: string, label: string, event: string, category: string}}
 */
export const userClickLogin = {
  event: 'user-click-login',
  category: 'user',
  action: 'click',
  label: 'login',
};

// -------------------------------------------------------
// EVERYWHERE
// -------------------------------------------------------
/**
 * GTM chatbot click
 */
export const chatBotClick = {
  event: 'user-click-chatbot',
  category: 'user',
  action: 'click',
  label: 'chatbot',
};

// -------------------------------------------------------
// CAMPAIGN
// -------------------------------------------------------
/**
 * toolbar
 */
export const campaignToolbarClick = {
  event: 'campaign-click-toolbar',
  category: 'campaign',
  action: 'click',
  label: 'toolbar',
};

/**
 * hero
 */
export const campaignHeroClick = {
  event: 'campaign-click-hero',
  category: 'campaign',
  action: 'click',
  label: 'hero',
};

/**
 * book a demo (middle section)
 */
export const campaignBookADemo = {
  event: 'campaign-click-Book-a-demo',
  category: 'campaign',
  action: 'click',
  label: 'book a demo',
};

/**
 * book a demo (footer)
 */
export const campaignBookADemoFooter = {
  event: 'campaign-click-footer',
  category: 'campaign',
  action: 'click',
  label: 'footer',
};
